package com.gic.store.web.controller;

import com.alibaba.fastjson.JSON;
import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.util.EntityUtil;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.download.utils.log.LogUtils;
import com.gic.enterprise.constants.Constants;
import com.gic.enterprise.utils.ResultControllerUtils;
import com.gic.enterprise.utils.UserDetailUtils;
import com.gic.store.constant.ClerkLogReasonEnum;
import com.gic.store.dto.ClerkDTO;
import com.gic.store.dto.ClerkLogDTO;
import com.gic.store.dto.ClerkSearchDTO;
import com.gic.store.service.ClerkApiService;
import com.gic.store.service.ClerkLogApiService;
import com.gic.store.web.qo.PageQO;
import com.gic.store.web.qo.clerk.ClerkQO;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * @author zhiwj
 * @date 2019/7/16
 */
@RestController
public class ClerkController {

    @Autowired
    private ClerkApiService clerkApiService;
    @Autowired
    private ClerkLogApiService clerkLogApiService;

    @RequestMapping("/list-clerk-field")
    public RestResponse listClerkField() {
        //language=JSON
        String json = "[{\"fliedName\":\"店员名称\",\"fliedCode\":\"clerkName\"},{\"fliedName\":\"店员唯一关联主键\",\"fliedCode\":\"clerkCode\"},{\"fliedName\":\"职位\",\"fliedCode\":\"positionName\"},{\"fliedName\":\"性别\",\"fliedCode\":\"clerkGender\"},{\"fliedName\":\"国际码\",\"fliedCode\":\"nationcode\"},{\"fliedName\":\"手机号\",\"fliedCode\":\"phoneNumber\"},{\"fliedName\":\"好办状态\",\"fliedCode\":\"haobanStatus\"},{\"fliedName\":\"启用状态\",\"fliedCode\":\"status\"}]";
        return RestResponse.success(JSON.parseArray(json));
    }

    @RequestMapping("/save-clerk")
    public RestResponse save(@Validated(ClerkQO.SaveValidView.class) ClerkQO clerkQO) {
        Integer enterpriseId = UserDetailUtils.getUserDetail().getEnterpriseId();
        ClerkDTO clerkDTO = EntityUtil.changeEntityByOrika(ClerkDTO.class, clerkQO);
        clerkDTO.setEnterpriseId(enterpriseId);
        clerkDTO.setReason(ClerkLogReasonEnum.WEB.getCode());
        if (clerkQO.getClerkId() == null) {
            clerkDTO.setRemark("手工新增");
        } else {
            clerkDTO.setRemark("单个编辑");
        }
        clerkDTO.setOperatorId(UserDetailUtils.getUserDetail().getUserId());
        clerkDTO.setOperatorName(UserDetailUtils.getUserDetail().getUserInfo().getUserName());
        ServiceResponse serviceResponse = clerkApiService.saveOrUpdate(clerkDTO);
        if (serviceResponse.isSuccess()) {
            LogUtils.createLog((clerkQO.getClerkId() == null ? "新增" : "修改") + "导购", clerkQO.getClerkName());
            return RestResponse.success(serviceResponse.getResult());
        } else {
            return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
        }
    }

    @RequestMapping("/list-clerk")
    public RestResponse listClerk(@RequestBody ClerkSearchDTO clerkSearchDTO) {
        Integer enterpriseId = UserDetailUtils.getUserDetail().getEnterpriseId();
        clerkSearchDTO.setEnterpriseId(enterpriseId);
        ServiceResponse serviceResponse = clerkApiService.listClerk(enterpriseId, clerkSearchDTO, clerkSearchDTO.getCurrentPage(), clerkSearchDTO.getPageSize());
        if (serviceResponse.isSuccess()) {
            return RestResponse.success(serviceResponse.getResult());
        } else {
            return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
        }
    }

    @RequestMapping("/update-clerk-status")
    public RestResponse updateClerkStatus(String clerkIds, Integer status) {
        Integer enterpriseId = UserDetailUtils.getUserDetail().getEnterpriseId();
        ServiceResponse<List<ClerkDTO>> listClerkByIds = clerkApiService.listClerkByIds(enterpriseId, clerkIds);
        ServiceResponse serviceResponse = clerkApiService.updateClerkStatus(enterpriseId, clerkIds, status);
        if (serviceResponse.isSuccess()) {
            List<ClerkDTO> clerkList = listClerkByIds.getResult();
            if (CollectionUtils.isNotEmpty(clerkList)) {
                String clerkNames = clerkList.stream().map(ClerkDTO::getClerkName).reduce((x, y) -> x + "," + y).orElse("");
                String statusName = (Constants.NORMAL_STATUS.equals(status)) ? "启用" : "禁用";
                LogUtils.createLog("修改状态为" + statusName, clerkNames);
            }
            return RestResponse.success(serviceResponse.getResult());
        } else {
            return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
        }
    }

    @RequestMapping("/list-clerk-log")
    public RestResponse listClerkLog(PageQO pageQO, String content, Integer reason, Integer logType, Integer clerkId) {
        ClerkLogDTO clerkLogDTO = new ClerkLogDTO();
        clerkLogDTO.setContent(content);
        clerkLogDTO.setReason(reason);
        clerkLogDTO.setLogType(logType);
        clerkLogDTO.setClerkId(clerkId);
        ServiceResponse<Page<ClerkLogDTO>> response = clerkLogApiService.listClerkLog(clerkLogDTO, pageQO.getCurrentPage(), pageQO.getPageSize());
        return ResultControllerUtils.commonResult(response);
    }

}
